/* This file is part of The_Merry_Turnip
 * 
 * The_Merry_Turnip - TODO: Description
 * Copyright © DAVY Guillaume 2009 <davyg2@gmail.com>
 * 
 * The_Merry_Turnip is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * The_Merry_Turnip is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
/*!	\file game.h
	\brief Main header file
	
	Contain all the include to the headers of: \n
	STL : vector\n
	irrlicht : irrlicht.h\n
	irrklang : irrklang.h\n
	The Merry Turnip : base.h, logger.h, item.h, staticMesh.h, actionMesh.h, local.h, inventaire.h, interface.h,
	console.h, lieu.h, chap.h, credit.h, coeur.h
*/

#ifndef __GAME_H_INCLUDED__
#define __GAME_H_INCLUDED__

// STL
#include <vector>
#include <iostream>
#include <fstream>
#include <string>

// Irrlicht
#include <irrlicht.h>
using namespace irr;
using namespace core;
using namespace scene;
using namespace video;
using namespace io;
using namespace gui;

// Irrklang
#ifdef AUDIO
#include <irrKlang.h>
using namespace irrklang;
#endif

// Boost for Python wrapping

#include <boost/python.hpp>
#include <boost/python/class.hpp>
#include <boost/python/module.hpp>
#include <boost/python/def.hpp>
using namespace boost::python;

//Declare some classes needed becasue of headers cross reference
class coeur;
class logger;
class startmenu;

//Include all the headers needed
#include <base.h>
#include <logger.h>
#include <pyInt.h>
#include <item.h>
#include <staticMesh.h>
#include <actionMesh.h>
#include <local.h>
#include <inventaire.h>
#include <interface.h>
#include <console.h>
#include <lieu.h>
#include <chap.h>
#include <credit.h>
#include <coeur.h>

#endif //__GAME_H_INCLUDED__

/*!
	\mainpage The Merry Turnip
	
	\image html navet-final.png
	\image latex navet-final.png
	
	\section intro Introduction
	
	Welcome to the The Merry Turnip code documentation.
	Here you'll find any information about the merry turnip code. \n
	
	First of all, it is coded in c++. I used only extreme programming when I coded it.\n

	\todo Description

	Compatible operating system :
		- Linux (Debian sure, others should too)
		- Windows (I have tested XP and Vista)
		- Mac is not compatible yet

	Library that I use :
		- STL
		- irrlicht 1.5 : 3d motor
		- irrklang 1.1.3 : sound motor

	Software i use to develop :
		- Debian Unstable(with experimental)
		- Gedit 2.22.3
		- GCC 4.3.3
		- GNU make 3.81
		- Gnome-terminal 2.24.1.1
		- Blender 2.46
		- The Gimp 2.4.7
		- Doxygen 1.5.6

	\sa
	http://merryturnip.tuxfamily.org/\n
	http://www.ambiera.com/irrklang/\n
	http://irrlicht.sourceforge.net/\n
	http://www.irrlicht.fr/\n

	\defgroup xml XML Scripts
	All the game can be configure by xml, this module contain a file by xml
	you can create to configure the game. \n
	Note that all path in xml are relative to the main.xml.\n
	main.xml, interface.xml, credit.xml must be unical whereas language.xml,
	chap.xml and lieu.xml can be numerous.
 */

